summaryrefslogtreecommitdiff
path: root/board/phytec/pcm030/pcm030.c
diff options
context:
space:
mode:
Diffstat (limited to 'board/phytec/pcm030/pcm030.c')
-rw-r--r--board/phytec/pcm030/pcm030.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/board/phytec/pcm030/pcm030.c b/board/phytec/pcm030/pcm030.c
index 19d8716..983559e 100644
--- a/board/phytec/pcm030/pcm030.c
+++ b/board/phytec/pcm030/pcm030.c
@@ -69,13 +69,13 @@ static void sdram_start(int hi_addr)
#endif
/*
* ATTENTION: Although partially referenced initdram does NOT make
* real use of CONFIG_SYS_SDRAM_BASE. The code does not
* work if CONFIG_SYS_SDRAM_BASE
* is something else than 0x00000000.
*/
-int initdram(void)
+int dram_init(void)
{
volatile struct mpc5xxx_mmap_ctl *mm =
(struct mpc5xxx_mmap_ctl *)CONFIG_SYS_MBAR;
@@ -69,13 +69,13 @@ static void sdram_start(int hi_addr)
#endif
/*
- * ATTENTION: Although partially referenced initdram does NOT make
+ * ATTENTION: Although partially referenced dram_init does NOT make
* real use of CONFIG_SYS_SDRAM_BASE. The code does not
* work if CONFIG_SYS_SDRAM_BASE